========================
:mod:`oujago.utils.file`
========================

.. automodule:: oujago.utils.file


.. autosummary::


Detailed Description
--------------------

.. autofunction:: join
.. autofunction:: mkdirs

